Module util

Module util 

Functions

as_unix_timestamp
build_api_url
build_steam_api_url
Builds a https://api.steampowered.com/<interface>/<method>/<version>?<params> URL.
get_cache_dir_path
get_json_filetype
get_steam_web_api_key
json_bool
Reads a boolean field from a JSON object, defaulting to false if absent or the wrong type.
json_f64
Reads a floating point field from a JSON object, defaulting to 0.0 if absent or the wrong type.
json_i64
Reads a signed integer field from a JSON object, defaulting to 0 if absent or the wrong type.
json_str
Reads a string field from a JSON object, defaulting to an empty string if absent or the wrong type.
json_u64
Reads an unsigned integer field from a JSON object, defaulting to 0 if absent or the wrong type.