Functions
- as_
unix_ timestamp - build_
api_ url - build_
steam_ api_ url - Builds a
https://api.steampowered.com/<interface>/<method>/<version>?<params>URL. - get_
cache_ dir_ path - get_
json_ filetype - get_
steam_ web_ api_ key - json_
bool - Reads a boolean field from a JSON object, defaulting to false if absent or the wrong type.
- json_
f64 - Reads a floating point field from a JSON object, defaulting to 0.0 if absent or the wrong type.
- json_
i64 - Reads a signed integer field from a JSON object, defaulting to 0 if absent or the wrong type.
- json_
str - Reads a string field from a JSON object, defaulting to an empty string if absent or the wrong type.
- json_
u64 - Reads an unsigned integer field from a JSON object, defaulting to 0 if absent or the wrong type.